/**
    @file ft51_uart_registers.h

    @brief UART registers library

    Registers and bit-masks for the high-performance UART.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_UART_REGISTERS_H__
#define __FT51_UART_REGISTERS_H__

#include "ft51_registers.h"
//------------------------------------------------------------------------------
// Register 96 (0x60) UART_CONTROL
#define UART_CONTROL                          0x60

// Register 96 Bit Definitions
#define BIT_UART_SOFT_RESET                   0                                 // Write a 1 to reset UART
#define MASK_UART_SOFT_RESET                  (0x1 << BIT_UART_SOFT_RESET)
#define BIT_UART_DEV_EN                       1                                 // Write a 1 to enable UART
#define MASK_UART_DEV_EN                      (0x1 << BIT_UART_DEV_EN)

//------------------------------------------------------------------------------
// Register 97 (0x61) UART_DMA_CTRL
#define UART_DMA_CTRL                           0x61

// Register 97 Bit Definitions
#define BIT_UART_DMA_ENA                      1                                 // Write 1 to put the UART block into DMA mode
#define MASK_UART_DMA_ENA                     (0x1 << BIT_UART_DMA_ENA)

//------------------------------------------------------------------------------
// Register 98 (0x62) UART_RX_DATA
#define UART_RX_DATA                   0x62

// Register 98 Bit Definitions
#define BIT_UART_DATA_RX_0                    0                                 // UART Peripheral Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_UART_DATA_RX_0                   (0x1 << BIT_UART_DATA_RX_0)
#define BIT_UART_DATA_RX_1                    1                                 // UART Peripheral Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_UART_DATA_RX_1                   (0x1 << BIT_UART_DATA_RX_1)
#define BIT_UART_DATA_RX_2                    2                                 // UART Peripheral Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_UART_DATA_RX_2                   (0x1 << BIT_UART_DATA_RX_2)
#define BIT_UART_DATA_RX_3                    3                                 // UART Peripheral Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_UART_DATA_RX_3                   (0x1 << BIT_UART_DATA_RX_3)
#define BIT_UART_DATA_RX_4                    4                                 // UART Peripheral Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_UART_DATA_RX_4                   (0x1 << BIT_UART_DATA_RX_4)
#define BIT_UART_DATA_RX_5                    5                                 // UART Peripheral Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_UART_DATA_RX_5                   (0x1 << BIT_UART_DATA_RX_5)
#define BIT_UART_DATA_RX_6                    6                                 // UART Peripheral Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_UART_DATA_RX_6                   (0x1 << BIT_UART_DATA_RX_6)
#define BIT_UART_DATA_RX_7                    7                                 // UART Peripheral Rx Data. Trigger will be used to indicate when data has been read out of the register.
#define MASK_UART_DATA_RX_7                   (0x1 << BIT_UART_DATA_RX_7)
#define MASK_UART_DATA_RX                     (0xFF << BIT_UART_DATA_RX_0)

//------------------------------------------------------------------------------
// Register 99 (0x63) UART_TX_DATA
#define UART_TX_DATA                  0x63

// Register 99 Bit Definitions
#define BIT_UART_DATA_TX_0                    0                                 // UART Peripheral Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_UART_DATA_TX_0                   (0x1 << BIT_UART_DATA_TX_0)
#define BIT_UART_DATA_TX_1                    1                                 // UART Peripheral Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_UART_DATA_TX_1                   (0x1 << BIT_UART_DATA_TX_1)
#define BIT_UART_DATA_TX_2                    2                                 // UART Peripheral Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_UART_DATA_TX_2                   (0x1 << BIT_UART_DATA_TX_2)
#define BIT_UART_DATA_TX_3                    3                                 // UART Peripheral Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_UART_DATA_TX_3                   (0x1 << BIT_UART_DATA_TX_3)
#define BIT_UART_DATA_TX_4                    4                                 // UART Peripheral Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_UART_DATA_TX_4                   (0x1 << BIT_UART_DATA_TX_4)
#define BIT_UART_DATA_TX_5                    5                                 // UART Peripheral Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_UART_DATA_TX_5                   (0x1 << BIT_UART_DATA_TX_5)
#define BIT_UART_DATA_TX_6                    6                                 // UART Peripheral Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_UART_DATA_TX_6                   (0x1 << BIT_UART_DATA_TX_6)
#define BIT_UART_DATA_TX_7                    7                                 // UART Peripheral Tx Data. Trigger will be used to indicate when new data has been written.
#define MASK_UART_DATA_TX_7                   (0x1 << BIT_UART_DATA_TX_7)
#define MASK_UART_DATA_TX                     (0xFF << BIT_UART_DATA_TX_0)

//------------------------------------------------------------------------------
// Register 100 (0x64) UART_TX_IEN
#define UART_TX_IEN                    0x64

// Register 100 Bit Definitions
#define BIT_UART_HOLD_TXE_IEN                 0                                 // Interrupt enable for uart_hold_txe_ien
#define MASK_UART_HOLD_TXE_IEN                (0x1 << BIT_UART_HOLD_TXE_IEN    )
#define BIT_UART_TX_DONE_IEN                  1                                 // Interrupt enable for uart_tx_done
#define MASK_UART_TX_DONE_IEN                 (0x1 << BIT_UART_TX_DONE_IEN)
#define BIT_UART_CTS_IEN                      2                                 // Interrupt enable for uart_cts_n
#define MASK_UART_CTS_IEN                     (0x1 << BIT_UART_CTS_IEN    )
#define BIT_UART_DSR_IEN                      3                                 // Interrupt enable for uart_dsr_n
#define MASK_UART_DSR_IEN                     (0x1 << BIT_UART_DSR_IEN    )
#define BIT_UART_RI_IEN                       4                                 // Interrupt enable for uart_ri
#define MASK_UART_RI_IEN                      (0x1 << BIT_UART_RI_IEN    )
#define BIT_UART_DCD_IEN                      5                                 // Interrupt enable for uart_dcd
#define MASK_UART_DCD_IEN                     (0x1 << BIT_UART_DCD_IEN    )

//------------------------------------------------------------------------------
// Register 101 (0x65) UART_TX_INT
#define UART_TX_INT                        0x65

// Register 101 Bit Definitions
#define BIT_UART_HOLD_TXE_INT                 0                                 // Tx holding register interrupt bit. Set on a low to high transition.
#define MASK_UART_HOLD_TXE_INT                (0x1 << BIT_UART_HOLD_TXE_INT)
#define BIT_UART_TX_DONE_INT                  1                                 // Tx state machine interrupt bit. Set when the state machine moves from busy to idle.
#define MASK_UART_TX_DONE_INT                 (0x1 << BIT_UART_TX_DONE_INT)
#define BIT_UART_CTS_INT                      2                                 // CTS interrupt bit. Should be set on any change in the state of cts.
#define MASK_UART_CTS_INT                     (0x1 << BIT_UART_CTS_INT)
#define BIT_UART_DSR_INT                      3                                 // DSR interrupt bit. Should be set on any change in the state of dsr.
#define MASK_UART_DSR_INT                     (0x1 << BIT_UART_DSR_INT)
#define BIT_UART_RI_INT                       4                                 // RI interrupt bit. Should be set on any change in the state of ri.
#define MASK_UART_RI_INT                      (0x1 << BIT_UART_RI_INT)
#define BIT_UART_DCD_INT                      5                                 // DCD interrupt bit. Should be set on any change in the state of dcd.
#define MASK_UART_DCD_INT                     (0x1 << BIT_UART_DCD_INT)
#define BIT_UART_TX_BUSY                      6                                 // When 1 this means that the tx state machine is busy processing a transfer.
#define MASK_UART_TX_BUSY                     (0x1 << BIT_UART_TX_BUSY)

//------------------------------------------------------------------------------
// Register 102 (0x66) UART_RX_IEN
#define UART_RX_IEN                    0x66

// Register 102 Bit Definitions
#define BIT_UART_RX_FULL_IEN                  0                                 // Interrupt enable for uart_rx_full
#define MASK_UART_RX_FULL_IEN                 (0x1 << BIT_UART_RX_FULL_IEN    )
#define BIT_UART_RX_OVERFLOW_IEN              1                                 // Interrupt enable for uart_rx_overflow
#define MASK_UART_RX_OVERFLOW_IEN             (0x1 << BIT_UART_RX_OVERFLOW_IEN)
#define BIT_UART_PARITY_ERROR_IEN             2                                 // Interrupt enable for uart_parity_error
#define MASK_UART_PARITY_ERROR_IEN            (0x1 << BIT_UART_PARITY_ERROR_IEN)
#define BIT_UART_STOP_ERROR_IEN               3                                 // Interrupt enable for uart_stop_error
#define MASK_UART_STOP_ERROR_IEN              (0x1 << BIT_UART_STOP_ERROR_IEN)
#define BIT_UART_BREAK_RCVD_IEN               4                                 // Interrupt enable for uart_break_rcvd
#define MASK_UART_BREAK_RCVD_IEN              (0x1 << BIT_UART_BREAK_RCVD_IEN)

//------------------------------------------------------------------------------
// Register 103 (0x67) UART_RX_INT
#define UART_RX_INT                        0x67

// Register 103 Bit Definitions
#define BIT_UART_RX_FULL_INT                  0                                 // Flag which indicates when Rx Data Register has received data and is ready to be read.
#define MASK_UART_RX_FULL_INT                 (0x1 << BIT_UART_RX_FULL_INT)
#define BIT_UART_RX_OVERFLOW_INT              1                                 // Indicates that an overflow error has occurred. This will happen when data is received, but the Rx data register has not been emptied in time.
#define MASK_UART_RX_OVERFLOW_INT             (0x1 << BIT_UART_RX_OVERFLOW_INT)
#define BIT_UART_PARITY_ERROR_INT             2                                 // Received data has an error with the Parity bit.
#define MASK_UART_PARITY_ERROR_INT            (0x1 << BIT_UART_PARITY_ERROR_INT)
#define BIT_UART_STOP_ERROR_INT               3                                 // When set this means that the last bit received was not a stop bit. This may occur due to a timing error.
#define MASK_UART_STOP_ERROR_INT              (0x1 << BIT_UART_STOP_ERROR_INT)
#define BIT_UART_BREAK_RCVD_INT               4                                 // This will be set when the received data line is held in logic state 0 for more than the time it takes to send a full word.
#define MASK_UART_BREAK_RCVD_INT              (0x1 << BIT_UART_BREAK_RCVD_INT)

//------------------------------------------------------------------------------
// Register 104 (0x68) UART_LINE_CTRL
#define UART_LINE_CTRL                      0x68

// Register 104 Bit Definitions
#define BIT_UART_SIZE_7                       0                                 // When enabled causes 7 bit data to be transmitted and received. Lower 7 bits of data registers are used.
#define MASK_UART_SIZE_7                      (0x1 << BIT_UART_SIZE_7)
#define BIT_UART_STOP_2                       1                                 // When enabled generates a high stop bit for two bit periods in stead of the usual one.
#define MASK_UART_STOP_2                      (0x1 << BIT_UART_STOP_2)
#define BIT_UART_PARITY_SEL_0                 2                                 // Parity Select Register
#define MASK_UART_PARITY_SEL_0                (0x1 << BIT_UART_PARITY_SEL_0)
#define BIT_UART_PARITY_SEL_1                 3                                 // Parity Select Register
#define MASK_UART_PARITY_SEL_1                (0x1 << BIT_UART_PARITY_SEL_1)
#define BIT_UART_PARITY_SEL_2                 4                                 // Parity Select Register
#define MASK_UART_PARITY_SEL_2                (0x1 << BIT_UART_PARITY_SEL_2)
#define MASK_UART_PARITY_SEL                  (0x7 << BIT_UART_PARITY_SEL_0)
#define BIT_UART_SET_BREAK                    5                                 // When active the txd line goes into spacing state which causes a break in the receiving UART. Setting back to 0 disables the break.
#define MASK_UART_SET_BREAK                   (0x1 << BIT_UART_SET_BREAK)

//------------------------------------------------------------------------------
// Register 105 (0x69) UART_BAUD_0
#define UART_BAUD_0                         0x69

// Register 105 Bit Definitions
#define BIT_UART_BAUD_REG_0_0                 0                                 // Lower 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_0_0                (0x1 << BIT_UART_BAUD_REG_0_0)
#define BIT_UART_BAUD_REG_0_1                 1                                 // Lower 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_0_1                (0x1 << BIT_UART_BAUD_REG_0_1)
#define BIT_UART_BAUD_REG_0_2                 2                                 // Lower 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_0_2                (0x1 << BIT_UART_BAUD_REG_0_2)
#define BIT_UART_BAUD_REG_0_3                 3                                 // Lower 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_0_3                (0x1 << BIT_UART_BAUD_REG_0_3)
#define BIT_UART_BAUD_REG_0_4                 4                                 // Lower 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_0_4                (0x1 << BIT_UART_BAUD_REG_0_4)
#define BIT_UART_BAUD_REG_0_5                 5                                 // Lower 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_0_5                (0x1 << BIT_UART_BAUD_REG_0_5)
#define BIT_UART_BAUD_REG_0_6                 6                                 // Lower 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_0_6                (0x1 << BIT_UART_BAUD_REG_0_6)
#define BIT_UART_BAUD_REG_0_7                 7                                 // Lower 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_0_7                (0x1 << BIT_UART_BAUD_REG_0_7)
#define MASK_UART_BAUD_REG_0                  (0xFF << BIT_UART_BAUD_REG_0_0)

//------------------------------------------------------------------------------
// Register 106 (0x6A) UART_BAUD_1
#define UART_BAUD_1                         0x6A

// Register 106 Bit Definitions
#define BIT_UART_BAUD_REG_1_0                 0                                 // Middle 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_1_0                (0x1 << BIT_UART_BAUD_REG_1_0)
#define BIT_UART_BAUD_REG_1_1                 1                                 // Middle 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_1_1                (0x1 << BIT_UART_BAUD_REG_1_1)
#define BIT_UART_BAUD_REG_1_2                 2                                 // Middle 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_1_2                (0x1 << BIT_UART_BAUD_REG_1_2)
#define BIT_UART_BAUD_REG_1_3                 3                                 // Middle 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_1_3                (0x1 << BIT_UART_BAUD_REG_1_3)
#define BIT_UART_BAUD_REG_1_4                 4                                 // Middle 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_1_4                (0x1 << BIT_UART_BAUD_REG_1_4)
#define BIT_UART_BAUD_REG_1_5                 5                                 // Middle 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_1_5                (0x1 << BIT_UART_BAUD_REG_1_5)
#define BIT_UART_BAUD_REG_1_6                 6                                 // Middle 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_1_6                (0x1 << BIT_UART_BAUD_REG_1_6)
#define BIT_UART_BAUD_REG_1_7                 7                                 // Middle 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_1_7                (0x1 << BIT_UART_BAUD_REG_1_7)
#define MASK_UART_BAUD_REG_1                  (0xFF << BIT_UART_BAUD_REG_1_0)

//------------------------------------------------------------------------------
// Register 107 (0x6B) UART_BAUD_2
#define UART_BAUD_2                         0x6B

// Register 107 Bit Definitions
#define BIT_UART_BAUD_REG_2_0                 0                                 // Upper 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_2_0                (0x1 << BIT_UART_BAUD_REG_2_0)
#define BIT_UART_BAUD_REG_2_1                 1                                 // Upper 8 bits of Baud Select register to determine the baud rate of the UART. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_REG_2_1                (0x1 << BIT_UART_BAUD_REG_2_1)
#define MASK_UART_BAUD_REG_2                  (0x3 << BIT_UART_BAUD_REG_2_0)
#define BIT_UART_BAUD_FRAC_0                  4                                 // Tuning bits for the baud rate controller. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_FRAC_0                 (0x1 << BIT_UART_BAUD_FRAC_0)
#define BIT_UART_BAUD_FRAC_1                  5                                 // Tuning bits for the baud rate controller. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_FRAC_1                 (0x1 << BIT_UART_BAUD_FRAC_1)
#define BIT_UART_BAUD_FRAC_2                  6                                 // Tuning bits for the baud rate controller. Trigger will be used to synchronise baud counter to new baud rate.
#define MASK_UART_BAUD_FRAC_2                 (0x1 << BIT_UART_BAUD_FRAC_2)
#define MASK_UART_BAUD_FRAC                   (0x7 << BIT_UART_BAUD_FRAC_0)

//------------------------------------------------------------------------------
// Register 108 (0x6C) UART_FLOW_CTRL
#define UART_FLOW_CTRL                      0x6C

// Register 108 Bit Definitions
#define BIT_UART_RTS_CTS                      0                                 // Flow control is set to RTS/CTS mode
#define MASK_UART_RTS_CTS                     (0x1 << BIT_UART_RTS_CTS)
#define BIT_UART_DTR_DSR                      1                                 // Flow control is set to DTR/DSR mode
#define MASK_UART_DTR_DSR                     (0x1 << BIT_UART_DTR_DSR)
#define BIT_UART_RTS_N_REG                    4                                 // Write 1 to force the rts_n output high. When 0, rts_n will be under the control of the flow control block.
#define MASK_UART_RTS_N_REG                   (0x1 << BIT_UART_RTS_N_REG)
#define BIT_UART_DTR_N_REG                    5                                 // Write 1 to force the dtr_n output high. When 0, dtr_n will be under the control of the flow control block.
#define MASK_UART_DTR_N_REG                   (0x1 << BIT_UART_DTR_N_REG)

//------------------------------------------------------------------------------
// Register 109 (0x6D) UART_FLOW_STAT
#define UART_FLOW_STAT                      0x6D

// Register 109 Bit Definitions
#define BIT_UART_CTS_N_REG                    0                                 // Status of the cts_n input.
#define MASK_UART_CTS_N_REG                   (0x1 << BIT_UART_CTS_N_REG)
#define BIT_UART_DSR_N_REG                    1                                 // Status of the dsr_n input.
#define MASK_UART_DSR_N_REG                   (0x1 << BIT_UART_DSR_N_REG)
#define BIT_UART_DCD_REG                      2                                 // Status of the dcd input.
#define MASK_UART_DCD_REG                     (0x1 << BIT_UART_DCD_REG)
#define BIT_UART_RI_REG                       3                                 // Status of the ri input.
#define MASK_UART_RI_REG                      (0x1 << BIT_UART_RI_REG)

#endif // __FT51_UART_REGISTERS_H__
